#!/bin/bash

N=$1
a=$2

if [[ "$a" == "" ]] ; then
    echo ""
    echo "Usage: `basename $0` N"
    echo ""
    echo "  N       Twin boundary every N (111) planes"
    echo "  a       FCC lattice constant"
    echo ""
    echo " This creates an Euler-compatible basis file with [111] in"
    echo " the z-direction and a twin boundary every N (111) planes."
    echo ""
    echo " Tommi Järvi, 30.11.2012."
    echo ""
    exit
fi


### Init

# Atoms on (111) planes
A[1]="Au  0.0        0.0      "  # 0.0           1"
A[2]="Au  0.5        0.5      "  # 0.0           1"
B[1]="Au  0.0        0.3333333"  # 0.3333333     1"
B[2]="Au  0.5        0.8333333"  # 0.3333333     1"
C[1]="Au  0.5        0.1666667"  # 0.6666667     1"
C[2]="Au  0.0        0.6666667"  # 0.6666667     1"

# Cell
v1="`gawk "BEGIN{print 0.707106781187*$a}"` 0.0 0.0"
v2="0.0 `gawk "BEGIN{print 1.22474487139*$a}"` 0.0"
bz="`gawk "BEGIN{print $a*(1.73205080757/3)*2*$N}"`"
v3="0.0 0.0 $bz"

# distance of (111) layers in z
d_normal="`gawk "BEGIN{print 1/3}"`"
d="`gawk "BEGIN{print $d_normal/(2*$N/3)}"`"


# Explanation
expl="(mode 1: vector components) fcc(111) unit cell with twin every $N planes (normal fcc(111) unit cell size a/sqrt(2), a*sqrt(3/2), a*sqrt(3))"

# Number of atoms
nat=`gawk "BEGIN{print (6/3)*2*$N}"`


### Create file

# header
echo "$nat"
echo "$v1  $v2  $v3  $expl"

# reset plane counter and z-coordinate
pl=0
z="0.0"
type="    1"

# Output bottom planes
for (( i=1 ; i<=$N ; i++ )) ; do
    # plane (1-3 = A-C)
    pl=`expr $pl + 1`
    if [[ $pl == 4 ]] ; then
	pl=1
    fi

    # output plane
    for (( j=1 ; j<=2 ; j++ )) ; do
	if [[ $pl == 1 ]] ; then
	    echo "${A[$j]}  $z $type"
	elif [[ $pl == 2 ]] ; then
	    echo "${B[$j]}  $z $type"
	elif [[ $pl == 3 ]] ; then
	    echo "${C[$j]}  $z $type"
	fi
    done

    z="`gawk "BEGIN{print $z + $d;}"`"
done

# Output mirror planes
for (( i=1 ; i<=$N ; i++ )) ; do

    # plane (1-3 = A-C)
    pl=`expr $pl - 1`
    if [[ $pl == 0 ]] ; then
	pl=3
    fi

    # output plane
    for (( j=1 ; j<=2 ; j++ )) ; do
	if [[ $pl == 1 ]] ; then
	    echo "${A[$j]}  $z $type"
	elif [[ $pl == 2 ]] ; then
	    echo "${B[$j]}  $z $type"
	elif [[ $pl == 3 ]] ; then
	    echo "${C[$j]}  $z $type"
	fi
    done

    z="`gawk "BEGIN{print $z + $d;}"`"
done
